# swagger
Welcome to the ORY Hydra HTTP API documentation. You will find documentation for all HTTP APIs here. Keep in mind that this document reflects the latest branch, always. Support for versioned documentation is coming in the future.

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: Latest
- Build package: io.swagger.codegen.languages.PhpClientCodegen
For more information, please visit [https://www.ory.sh](https://www.ory.sh)

## Requirements

PHP 5.4.0 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/ory/swagger.git"
    }
  ],
  "require": {
    "ory/swagger": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/swagger/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new Hydra\SDK\Api\HealthApi();

try {
    $result = $api_instance->isInstanceAlive();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling HealthApi->isInstanceAlive: ', $e->getMessage(), PHP_EOL;
}

?>
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*HealthApi* | [**isInstanceAlive**](docs/Api/HealthApi.md#isinstancealive) | **GET** /health/alive | Check the Alive Status
*HealthApi* | [**isInstanceReady**](docs/Api/HealthApi.md#isinstanceready) | **GET** /health/ready | Check the Readiness Status
*JsonWebKeyApi* | [**createJsonWebKeySet**](docs/Api/JsonWebKeyApi.md#createjsonwebkeyset) | **POST** /keys/{set} | Generate a new JSON Web Key
*JsonWebKeyApi* | [**deleteJsonWebKey**](docs/Api/JsonWebKeyApi.md#deletejsonwebkey) | **DELETE** /keys/{set}/{kid} | Delete a JSON Web Key
*JsonWebKeyApi* | [**deleteJsonWebKeySet**](docs/Api/JsonWebKeyApi.md#deletejsonwebkeyset) | **DELETE** /keys/{set} | Delete a JSON Web Key Set
*JsonWebKeyApi* | [**getJsonWebKey**](docs/Api/JsonWebKeyApi.md#getjsonwebkey) | **GET** /keys/{set}/{kid} | Retrieve a JSON Web Key
*JsonWebKeyApi* | [**getJsonWebKeySet**](docs/Api/JsonWebKeyApi.md#getjsonwebkeyset) | **GET** /keys/{set} | Retrieve a JSON Web Key Set
*JsonWebKeyApi* | [**updateJsonWebKey**](docs/Api/JsonWebKeyApi.md#updatejsonwebkey) | **PUT** /keys/{set}/{kid} | Update a JSON Web Key
*JsonWebKeyApi* | [**updateJsonWebKeySet**](docs/Api/JsonWebKeyApi.md#updatejsonwebkeyset) | **PUT** /keys/{set} | Update a JSON Web Key Set
*MetricsApi* | [**getPrometheusMetrics**](docs/Api/MetricsApi.md#getprometheusmetrics) | **GET** /metrics/prometheus | Retrieve Prometheus metrics
*OAuth2Api* | [**acceptConsentRequest**](docs/Api/OAuth2Api.md#acceptconsentrequest) | **PUT** /oauth2/auth/requests/consent/{challenge}/accept | Accept an consent request
*OAuth2Api* | [**acceptLoginRequest**](docs/Api/OAuth2Api.md#acceptloginrequest) | **PUT** /oauth2/auth/requests/login/{challenge}/accept | Accept an login request
*OAuth2Api* | [**createOAuth2Client**](docs/Api/OAuth2Api.md#createoauth2client) | **POST** /clients | Create an OAuth 2.0 client
*OAuth2Api* | [**deleteOAuth2Client**](docs/Api/OAuth2Api.md#deleteoauth2client) | **DELETE** /clients/{id} | Deletes an OAuth 2.0 Client
*OAuth2Api* | [**flushInactiveOAuth2Tokens**](docs/Api/OAuth2Api.md#flushinactiveoauth2tokens) | **POST** /oauth2/flush | Flush Expired OAuth2 Access Tokens
*OAuth2Api* | [**getConsentRequest**](docs/Api/OAuth2Api.md#getconsentrequest) | **GET** /oauth2/auth/requests/consent/{challenge} | Get consent request information
*OAuth2Api* | [**getLoginRequest**](docs/Api/OAuth2Api.md#getloginrequest) | **GET** /oauth2/auth/requests/login/{challenge} | Get an login request
*OAuth2Api* | [**getOAuth2Client**](docs/Api/OAuth2Api.md#getoauth2client) | **GET** /clients/{id} | Get an OAuth 2.0 Client.
*OAuth2Api* | [**getWellKnown**](docs/Api/OAuth2Api.md#getwellknown) | **GET** /.well-known/openid-configuration | Server well known configuration
*OAuth2Api* | [**introspectOAuth2Token**](docs/Api/OAuth2Api.md#introspectoauth2token) | **POST** /oauth2/introspect | Introspect OAuth2 tokens
*OAuth2Api* | [**listOAuth2Clients**](docs/Api/OAuth2Api.md#listoauth2clients) | **GET** /clients | List OAuth 2.0 Clients
*OAuth2Api* | [**listUserConsentSessions**](docs/Api/OAuth2Api.md#listuserconsentsessions) | **GET** /oauth2/auth/sessions/consent/{user} | Lists all consent sessions of a user
*OAuth2Api* | [**oauthAuth**](docs/Api/OAuth2Api.md#oauthauth) | **GET** /oauth2/auth | The OAuth 2.0 authorize endpoint
*OAuth2Api* | [**oauthToken**](docs/Api/OAuth2Api.md#oauthtoken) | **POST** /oauth2/token | The OAuth 2.0 token endpoint
*OAuth2Api* | [**rejectConsentRequest**](docs/Api/OAuth2Api.md#rejectconsentrequest) | **PUT** /oauth2/auth/requests/consent/{challenge}/reject | Reject an consent request
*OAuth2Api* | [**rejectLoginRequest**](docs/Api/OAuth2Api.md#rejectloginrequest) | **PUT** /oauth2/auth/requests/login/{challenge}/reject | Reject a login request
*OAuth2Api* | [**revokeAllUserConsentSessions**](docs/Api/OAuth2Api.md#revokealluserconsentsessions) | **DELETE** /oauth2/auth/sessions/consent/{user} | Revokes all previous consent sessions of a user
*OAuth2Api* | [**revokeAuthenticationSession**](docs/Api/OAuth2Api.md#revokeauthenticationsession) | **DELETE** /oauth2/auth/sessions/login/{user} | Invalidates a user&#39;s authentication session
*OAuth2Api* | [**revokeOAuth2Token**](docs/Api/OAuth2Api.md#revokeoauth2token) | **POST** /oauth2/revoke | Revoke OAuth2 tokens
*OAuth2Api* | [**revokeUserClientConsentSessions**](docs/Api/OAuth2Api.md#revokeuserclientconsentsessions) | **DELETE** /oauth2/auth/sessions/consent/{user}/{client} | Revokes consent sessions of a user for a specific OAuth 2.0 Client
*OAuth2Api* | [**revokeUserLoginCookie**](docs/Api/OAuth2Api.md#revokeuserlogincookie) | **GET** /oauth2/auth/sessions/login/revoke | Logs user out by deleting the session cookie
*OAuth2Api* | [**updateOAuth2Client**](docs/Api/OAuth2Api.md#updateoauth2client) | **PUT** /clients/{id} | Update an OAuth 2.0 Client
*OAuth2Api* | [**userinfo**](docs/Api/OAuth2Api.md#userinfo) | **POST** /userinfo | OpenID Connect Userinfo
*OAuth2Api* | [**wellKnown**](docs/Api/OAuth2Api.md#wellknown) | **GET** /.well-known/jwks.json | Get Well-Known JSON Web Keys
*VersionApi* | [**getVersion**](docs/Api/VersionApi.md#getversion) | **GET** /version | Get the version of Hydra


## Documentation For Models

 - [AcceptConsentRequest](docs/Model/AcceptConsentRequest.md)
 - [AcceptLoginRequest](docs/Model/AcceptLoginRequest.md)
 - [AttributeTypeAndValue](docs/Model/AttributeTypeAndValue.md)
 - [AuthenticationSession](docs/Model/AuthenticationSession.md)
 - [Certificate](docs/Model/Certificate.md)
 - [CompletedRequest](docs/Model/CompletedRequest.md)
 - [ConsentRequest](docs/Model/ConsentRequest.md)
 - [ConsentRequestSession](docs/Model/ConsentRequestSession.md)
 - [ExtKeyUsage](docs/Model/ExtKeyUsage.md)
 - [Extension](docs/Model/Extension.md)
 - [FlushInactiveOAuth2TokensRequest](docs/Model/FlushInactiveOAuth2TokensRequest.md)
 - [HealthNotReadyStatus](docs/Model/HealthNotReadyStatus.md)
 - [HealthStatus](docs/Model/HealthStatus.md)
 - [IP](docs/Model/IP.md)
 - [IPMask](docs/Model/IPMask.md)
 - [IPNet](docs/Model/IPNet.md)
 - [InlineResponse401](docs/Model/InlineResponse401.md)
 - [Int](docs/Model/Int.md)
 - [JSONWebKey](docs/Model/JSONWebKey.md)
 - [JSONWebKeySet](docs/Model/JSONWebKeySet.md)
 - [JoseWebKeySetRequest](docs/Model/JoseWebKeySetRequest.md)
 - [JsonWebKey](docs/Model/JsonWebKey.md)
 - [JsonWebKeySet](docs/Model/JsonWebKeySet.md)
 - [JsonWebKeySetGeneratorRequest](docs/Model/JsonWebKeySetGeneratorRequest.md)
 - [KeyUsage](docs/Model/KeyUsage.md)
 - [LoginRequest](docs/Model/LoginRequest.md)
 - [Name](docs/Model/Name.md)
 - [OAuth2Client](docs/Model/OAuth2Client.md)
 - [OAuth2TokenIntrospection](docs/Model/OAuth2TokenIntrospection.md)
 - [OauthTokenResponse](docs/Model/OauthTokenResponse.md)
 - [ObjectIdentifier](docs/Model/ObjectIdentifier.md)
 - [OpenIDConnectContext](docs/Model/OpenIDConnectContext.md)
 - [PreviousConsentSession](docs/Model/PreviousConsentSession.md)
 - [PublicKeyAlgorithm](docs/Model/PublicKeyAlgorithm.md)
 - [RawMessage](docs/Model/RawMessage.md)
 - [RejectRequest](docs/Model/RejectRequest.md)
 - [SignatureAlgorithm](docs/Model/SignatureAlgorithm.md)
 - [SwaggerFlushInactiveAccessTokens](docs/Model/SwaggerFlushInactiveAccessTokens.md)
 - [SwaggerJsonWebKeyQuery](docs/Model/SwaggerJsonWebKeyQuery.md)
 - [SwaggerJwkCreateSet](docs/Model/SwaggerJwkCreateSet.md)
 - [SwaggerJwkSetQuery](docs/Model/SwaggerJwkSetQuery.md)
 - [SwaggerJwkUpdateSet](docs/Model/SwaggerJwkUpdateSet.md)
 - [SwaggerJwkUpdateSetKey](docs/Model/SwaggerJwkUpdateSetKey.md)
 - [SwaggerOAuthIntrospectionRequest](docs/Model/SwaggerOAuthIntrospectionRequest.md)
 - [SwaggerRevokeOAuth2TokenParameters](docs/Model/SwaggerRevokeOAuth2TokenParameters.md)
 - [URL](docs/Model/URL.md)
 - [Userinfo](docs/Model/Userinfo.md)
 - [UserinfoResponse](docs/Model/UserinfoResponse.md)
 - [Version](docs/Model/Version.md)
 - [WellKnown](docs/Model/WellKnown.md)


## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication

## oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://your-hydra-instance.com/oauth2/auth
- **Scopes**: 
 - **offline**: A scope required when requesting refresh tokens
 - **openid**: Request an OpenID Connect ID Token


## Author

hi@ory.am


